==========
User Guide
==========

This user guide covers essential features of pysal-inequality, mostly in the form of interactive Jupyter notebooks. Reading this guide, you will learn:

- how to :ref:`visualize <viz>` spatial inequality
- how to :ref:`measure <measure>` spatial inequality

Notebooks cover just a small selection of functions as an illustration of
principles. For a full overview of pysal-inequality capabilities, head to the `API <../api.rst>`_.

